// Copyright 2021 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

#[doc = include_str!("impls/builder.md")]
pub mod builder {}
pub mod bumpalo;
pub mod either;
pub mod empty;
pub mod merged;
pub mod option;
pub mod simple;
#[doc = include_str!("impls/traits.md")]
pub mod traits {}
